==> haskell-html-entity-map-0.1.0.0-258-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-html-entity-map.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 html-entity-map
version:              0.1.0.0
visibility:           public
id:                   html-entity-map-0.1.0.0-B8jjHLDXOF5ItIZ0sCT8sU
key:                  html-entity-map-0.1.0.0-B8jjHLDXOF5ItIZ0sCT8sU
license:              BSD-3-Clause
maintainer:           Mark Karpov <markkarpov92@gmail.com>
author:               Mark Karpov <markkarpov92@gmail.com>
homepage:             https://github.com/mrkkrp/html-entity-map
synopsis:
    Map from HTML5 entity names to the corresponding Unicode text

description:
    Map from HTML5 entity names to the corresponding Unicode text.

category:             HTML
abi:                  10920d8e5b9d60cbb9c2e2e59e8d1e50
exposed:              True
exposed-modules:      Data.HTML.Entities
import-dirs:          /usr/lib/ghc-9.4.8/site-local/html-entity-map-0.1.0.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/html-entity-map-0.1.0.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/html-entity-map-0.1.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-html-entity-map
hs-libraries:         HShtml-entity-map-0.1.0.0-B8jjHLDXOF5ItIZ0sCT8sU
depends:
    base-4.17.2.1 text-2.0.2
    unordered-containers-0.2.20-FLM1pZb3BI5FpyNo5sVXNv

haddock-interfaces:
    /usr/share/doc/haskell-html-entity-map/html/html-entity-map.haddock

haddock-html:         /usr/share/doc/haskell-html-entity-map/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-html-entity-map-0.1.0.0-259-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-html-entity-map.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 html-entity-map
version:              0.1.0.0
visibility:           public
id:                   html-entity-map-0.1.0.0-Hqu2qGnHX7Z8AOxy6Zgn4Y
key:                  html-entity-map-0.1.0.0-Hqu2qGnHX7Z8AOxy6Zgn4Y
license:              BSD-3-Clause
maintainer:           Mark Karpov <markkarpov92@gmail.com>
author:               Mark Karpov <markkarpov92@gmail.com>
homepage:             https://github.com/mrkkrp/html-entity-map
synopsis:
    Map from HTML5 entity names to the corresponding Unicode text

description:
    Map from HTML5 entity names to the corresponding Unicode text.

category:             HTML
abi:                  70ed350e409550bfb97d6375eed8aab4
exposed:              True
exposed-modules:      Data.HTML.Entities
import-dirs:          /usr/lib/ghc-9.4.8/site-local/html-entity-map-0.1.0.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/html-entity-map-0.1.0.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/html-entity-map-0.1.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-html-entity-map
hs-libraries:         HShtml-entity-map-0.1.0.0-Hqu2qGnHX7Z8AOxy6Zgn4Y
depends:
    base-4.17.2.1 text-2.0.2
    unordered-containers-0.2.20-I3GOf8berWn8tol6ImoSEe

haddock-interfaces:
    /usr/share/doc/haskell-html-entity-map/html/html-entity-map.haddock

haddock-html:         /usr/share/doc/haskell-html-entity-map/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
